@@ -5,8 +5,6 @@ from logging.handlers import TimedRotatingFileHandler
 FORMATTER = formatter = logging.Formatter(
     '%(asctime)s - %(name)s - %(message)s')
 
-LOG_FILE = "./logs"
-
 
 def get_console_handler():
     console_handler = logging.StreamHandler(sys.stdout)
@@ -14,18 +12,11 @@ def get_console_handler():
     return console_handler
 
 
-def get_file_handler():
-    file_handler = TimedRotatingFileHandler(LOG_FILE, when='midnight')
-    file_handler.setFormatter(FORMATTER)
-    return file_handler
-
-
 def get_logger(logger_name='efsync'):
     logger = logging.getLogger(logger_name)
     # better to have too much log than not enough
     logger.setLevel(logging.DEBUG)
     logger.addHandler(get_console_handler())
-    logger.addHandler(get_file_handler())
     # with this pattern, it's rarely necessary to propagate the error up to parent
     logger.propagate = False
     return logger
